# analyze
For installing and using the code, see the documentation [on readthedocs](https://analyze.readthedocs.io/en/latest/)

For contributing, see the [github](https://github.com/aolabNeuro/analyze/)
